======
pyRTID
======

|License| |Stars| |Python| |PyPI| |Downloads| |Build Status| |Documentation Status| |Coverage| |Codacy| |Precommit: enabled| |Ruff| |ty| |DOI|

The Python Reactive Transport Inversion Demonstrator.

Reactive Transport Inversion is a reactive transport inversion demonstrator written in Python.

🏗️ Complete example with supporting paper coming Q1 2026.

===========
🔑 License
===========

This project is released under the **BSD 3-Clause License**.

Copyright (c) 2024-2026, Antoine COLLET. All rights reserved.

For more details, see the `LICENSE <https://github.com/antoinecollet5/pyrtid/blob/master/LICENSE>`_ file included in this repository.

==============
⚠️ Disclaimer
==============

This software is provided "as is", without warranty of any kind, express or implied,
including but not limited to the warranties of merchantability, fitness for a particular purpose,
or non-infringement. In no event shall the authors or copyright holders be liable for
any claim, damages, or other liability, whether in an action of contract, tort,
or otherwise, arising from, out of, or in connection with the software or the use
or other dealings in the software.

By using this software, you agree to accept full responsibility for any consequences,
and you waive any claims against the authors or contributors.

==========
📧 Contact
==========

For questions, suggestions, or contributions, you can reach out via:

- Email: antoinecollet5@gmail.com
- GitHub: https://github.com/antoinecollet5/pyrtid

We welcome contributions!

=============
📚 References
=============

[1] Antoine Collet. Assisted history matching in reactive transport :
Application to uranium in situ recovery. Environmental Engineering.
Université Paris sciences et lettres, 2024. English. ⟨NNT : 2024UPSLM064⟩. ⟨tel-05097765⟩

[2] Antoine Collet, Irina Sin, Hervé Chauris, Valérie Langlais, Olivier Regnault,
Impact of time and spatial discretization on adjoint operators:
Example of stationary and transient saturated flows,
Advances in Water Resources, Volume 205, 2025, 105070,
ISSN 0309-1708, https://doi.org/10.1016/j.advwatres.2025.105070.

* Free software: SPDX-License-Identifier: BSD-3-Clause


.. |License| image:: https://img.shields.io/badge/License-BSD_3--Clause-blue.svg
    :target: https://github.com/antoinecollet5/lbfgsb/blob/master/LICENSE

.. |Stars| image:: https://img.shields.io/github/stars/antoinecollet5/pyrtid.svg?style=social&label=Star&maxAge=2592000
    :target: https://github.com/antoinecollet5/pyrtid/stargazers
    :alt: Stars

.. |Python| image:: https://img.shields.io/pypi/pyversions/pyrtid.svg
    :target: https://pypi.org/pypi/pyrtid
    :alt: Python

.. |PyPI| image:: https://img.shields.io/pypi/v/pyrtid.svg
    :target: https://pypi.org/pypi/pyrtid
    :alt: PyPI

.. |Downloads| image:: https://static.pepy.tech/badge/pyrtid
    :target: https://pepy.tech/project/pyrtid
    :alt: Downoads


.. |Build Status| image:: https://github.com/antoinecollet5/pyrtid/actions/workflows/main.yml/badge.svg
    :target: https://github.com/antoinecollet5/pyrtid/actions/workflows/main.yml
    :alt: Build Status

.. |Documentation Status| image:: https://readthedocs.org/projects/pyrtid/badge/?version=latest
    :target: https://pyrtid.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |Coverage| image:: https://codecov.io/gh/antoinecollet5/pyrtid/branch/master/graph/badge.svg?token=ISE874MMOF
    :target: https://codecov.io/gh/antoinecollet5/pyrtid
    :alt: Coverage

.. |Codacy| image:: https://app.codacy.com/project/badge/Grade/de7e2aa515894571aa2bbb43c33ada2c
    :target: https://app.codacy.com/gh/antoinecollet5/pyrtid/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade
    :alt: codacy

.. |Precommit: enabled| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit
   :target: https://github.com/pre-commit/pre-commit

.. |Ruff| image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
    :target: https://github.com/astral-sh/ruff
    :alt: Ruff

.. |ty| image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ty/main/assets/badge/v0.json
    :target: https://github.com/astral-sh/ty
    :alt: Checked with ty

.. |DOI| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.8192031.svg
   :target: https://doi.org/10.5281/zenodo.8192031
